import { ShContextService } from './sh-context-service';
import { Directive, Input, HostListener, Output, EventEmitter } from "@angular/core";
import { ShContextOverlayComponent } from './sh-context-overlay.component';
import { ShContextMenuComponent } from "./sh-context-menu.component";
import { InjectionService } from "./injector.service";
var ShContextMenuDirective = (function () {
    function ShContextMenuDirective(ctxService, injectionService) {
        this.ctxService = ctxService;
        this.injectionService = injectionService;
        this.onBeforeMenuOpen = new EventEmitter();
    }
    ShContextMenuDirective.prototype.onClick = function (event) {
        var _this = this;
        this.options = this.ctxService.setOptions(this.options);
        this.closeMenu();
        if (this.onBeforeMenuOpen.observers.length > 0) {
            this.onBeforeMenuOpen.emit({
                event: event,
                items: this.menuItems,
                open: function (modifiedItems) {
                    if (modifiedItems === void 0) { modifiedItems = _this.menuItems; }
                    return _this.createMenu(event, modifiedItems);
                }
            });
        }
        else {
            this.createMenu(event);
        }
        return false;
    };
    ShContextMenuDirective.prototype.createMenu = function (event, items) {
        if (items === void 0) { items = this.menuItems; }
        this.overlayComponent = this.createOverlayComponent();
        this.ctxComponent = this.createContextComponent();
        this.registerBindings(items);
        this.registerEvents();
        this.setLocation(event);
    };
    ShContextMenuDirective.prototype.registerEvents = function () {
        var _this = this;
        this.ctxComponent.instance.onClose.subscribe(function () {
            _this.closeMenu();
        });
        this.overlayComponent.instance.onClick.subscribe(function () {
            _this.closeMenu();
        });
    };
    ShContextMenuDirective.prototype.registerBindings = function (menuItems) {
        this.ctxComponent.instance.items = menuItems;
        this.ctxComponent.instance.dataContext = this.dataContext;
    };
    ShContextMenuDirective.prototype.createContextComponent = function () {
        return this.injectionService.appendComponent(ShContextMenuComponent);
    };
    ShContextMenuDirective.prototype.createOverlayComponent = function () {
        return this.injectionService.appendComponent(ShContextOverlayComponent);
    };
    ShContextMenuDirective.prototype.setLocation = function (event) {
        var clientX = event.clientX, clientY = event.clientY;
        this.ctxComponent.instance.position = {
            top: clientY,
            left: clientX
        };
    };
    ShContextMenuDirective.prototype.closeMenu = function () {
        if (this.ctxComponent)
            this.ctxComponent.destroy();
        if (this.overlayComponent)
            this.overlayComponent.destroy();
    };
    return ShContextMenuDirective;
}());
export { ShContextMenuDirective };
ShContextMenuDirective.decorators = [
    { type: Directive, args: [{
                selector: '[sh-context]'
            },] },
];
/** @nocollapse */
ShContextMenuDirective.ctorParameters = function () { return [
    { type: ShContextService, },
    { type: InjectionService, },
]; };
ShContextMenuDirective.propDecorators = {
    'menuItems': [{ type: Input, args: ['sh-context',] },],
    'dataContext': [{ type: Input, args: ['sh-data-context',] },],
    'options': [{ type: Input, args: ['sh-options',] },],
    'onBeforeMenuOpen': [{ type: Output, args: ['onBeforeMenuOpen',] },],
    'onClick': [{ type: HostListener, args: ['contextmenu', ['$event'],] },],
};
//# sourceMappingURL=sh-context-menu.directive.js.map